@@ -4,6 +4,7 @@ typedef enum {
     json_error_unexpected_end_of_input,
     json_error_not_surrogate_pair,
     json_error_empty_input,
+    json_error_name_is_not_unique,
     json_error_overflow
 }
 json_error_t;
@@ -14,6 +15,7 @@ const char * json_errors[json_error_overflow] = {
     "Unexpected end of input",
     "Not surrogate pair",
     "Empty input",
+    "Name is not unique",
 };
 enum expectation {
     xwhitespace,
